import type { Metadata } from 'next';
import localFont from 'next/font/local';

import Header from '@/components/header/header';
import Footer from '@/components/footer/footer';
import Banner from '@/components/banner/banner';
import './globals.css';

const font = localFont({
  src: '../public/fonts/IBMPlexSans.ttf',
  weight: '500',
  variable: '--font-ibm-plex'
});

export const metadata: Metadata = {
  title: "Hello, I'm Rory",
  description: 'The personal website of Rory Healy.',
  icons: {
    icon: 'favicon.svg'
  }
};

export default function RootLayout({ children }: { children: React.ReactNode }) {
  return (
    <html lang='en'>
      <body>
        <main className={`flex flex-col h-screen w-screen bg-custom-grey-1 ${font.className}`}>
          <Banner />
          <Header />
          <div className='flex flex-1 h-full w-full items-center justify-center'>{children}</div>
          <Footer />
        </main>
      </body>
    </html>
  );
}
