'use client';

import { useState } from 'react';
import Image from 'next/image';

export default function Projects() {
  const [selectedTab, setSelectedTab] = useState(0);
  const MAX_TABS = 4;

  function LeftButton() {
    const changeTab = () => {
      setSelectedTab(selectedTab == 0 ? MAX_TABS - 1 : selectedTab - 1);
    };
    return (
      <div
        className='absolute z-10 flex justify-start top-0 left-0 w-48 h-full bg-gradient-to-r from-custom-grey-1 opacity-0 hover:opacity-100 transition-opacity duration-200 ease-in'
        onClick={changeTab}
      >
        <Image alt='Right arrow' src='images/dark/arrow.svg' width={50} height={50} className='rotate-180' />
      </div>
    );
  }
  function RightButton() {
    const changeTab = () => {
      setSelectedTab(selectedTab == MAX_TABS - 1 ? 0 : selectedTab + 1);
    };
    return (
      <div
        className='absolute z-10 flex justify-end top-0 right-0 w-48 h-full bg-gradient-to-l from-custom-grey-1 opacity-0 hover:opacity-100 transition-opacity duration-200 ease-in'
        onClick={changeTab}
      >
        <Image alt='Right arrow' src='images/dark/arrow.svg' width={50} height={50} />
      </div>
    );
  }

  return (
    <div className='w-[90%] h-[90%] flex'>
      <div className='w-full h-full flex flex-col z-0'>
        {/* Main content */}
        <div className='bg-custom-grey-2 flex-1 relative'>
          <div className={`flex flex-col h-full ${selectedTab == 0 ? 'visible' : 'hidden'}`}>
            <div className='flex-1 w-full relative'>
              <LeftButton />
              <Image
                src='/images/projects/workoutbuddy.jpg'
                alt='Workout Buddy Front Page'
                fill
                className='object-contain'
                priority
              />
              <RightButton />
            </div>
            <p className='p-2 bg-gradient-to-t from-custom-grey-3 to-gray-500'>
              <a href='https://github.com/samarthkhandelwal/IT-Project' className='text-custom-blue-2'>
                Workout Buddy
              </a>{' '}
              is an online application designed to help people find exercises and workout plans, as well as create their
              own workout plans. This is the capstone project that myself and four other students worked on during our
              studies. We worked with our client to design.
            </p>
          </div>

          <div className={`flex flex-col h-full ${selectedTab == 1 ? 'visible' : 'hidden'}`}>
            <div className='flex-1 w-full relative bg-[#1D1D1F]'>
              <LeftButton />
              <Image src='images/projects/themyrtletree.svg' alt='The Myrtle Tree Front Page' fill priority />
              <RightButton />
            </div>
            <p className='p-2 bg-gradient-to-t from-custom-grey-3 to-gray-500'>
              <a href='https://themyrtletree.roryhealy.dev' className='text-custom-blue-2'>
                The Myrtle Tree
              </a>{' '}
              is a narrative game about a young Australian woman reconnecting with the sounds in her life through her
              memories. The character you play is a young musician named Clara. She has experienced a significant loss
              of hearing, which has greatly impacted her life. Waiting for her cochlear implants, she relives some of
              her memories and the sounds that she can still remember, and forms new memories once she has partially
              restored her hearing.
            </p>
          </div>

          <div className={`flex flex-col h-full ${selectedTab == 2 ? 'visible' : 'hidden'}`}>
            <div className='flex-1 w-full relative'>
              <LeftButton />
              <Image
                src='/images/projects/myglucose.jpg'
                alt='MyGlucose Front Page'
                fill
                priority
                className='object-contain'
              />
              <RightButton />
            </div>
            <p className='p-2 bg-gradient-to-t from-custom-grey-3 to-gray-500'>
              <a href='https://github.com/bttan-uom/projectxy' className='text-custom-blue-2'>
                MyGlucose
              </a>{' '}
              is a web app that helps people to manage their diabetes in the convenience of their own home, recording
              data that can be monitored remotely by their clinician.
            </p>
          </div>

          <div className={`flex flex-col h-full ${selectedTab == 3 ? 'visible' : 'hidden'}`}>
            <div className='flex-1 w-full relative'>
              <LeftButton />
              <Image
                src='/images/projects/website.jpg'
                alt='Personal website front page'
                fill
                className='object-contain'
                priority
              />
              <RightButton />
            </div>
            <p className='p-2 bg-gradient-to-t from-custom-grey-3 to-gray-500'>
              <a href='https://roryhealy.dev' className='text-custom-blue-2'>
                roryhealy.dev
              </a>{' '}
              is my personal website that I created to showcase the projects I have worked on during my studies at
              university. I host my own Gitea instance, where you can view the source code for my projects.
            </p>
          </div>
        </div>

        {/* Navigation */}
        <div className='bg-custom-grey-3 h-10 flex items-center justify-center gap-3'>
          {[...Array(MAX_TABS).keys()].map((i) => (
            <div
              key={`tab-${i}`}
              className={`${
                selectedTab == i ? 'bg-custom-blue-1' : 'bg-custom-white hover:bg-custom-white-2'
              } w-2 h-2 rounded-full`}
              onClick={() => setSelectedTab(i)}
            ></div>
          ))}
        </div>
      </div>
    </div>
  );
}
