'use client';

import { useEffect, useState } from 'react';

interface IMousePosition {
  x: number | null;
  y: number | null;
}

const useMousePosition = () => {
  const initialPosition: IMousePosition = { x: null, y: null }
  const [mousePosition, setMousePosition] = useState(initialPosition);

  useEffect(() => {
    const updateMousePosition = (event: IMousePosition) => {
      setMousePosition({ x: event.x, y: event.y });
    };

    window.addEventListener('mousemove', updateMousePosition);
    return () => {
      window.removeEventListener('mousemove', updateMousePosition);
    };
  }, []);

  return mousePosition;
};

export default useMousePosition;
